//
// Bottom half of an enclosure for Miniware DT71 battery and charger circuit.
// Contains electronics.
//
// Dimensions are mm
//
// Version 1.0 - Initial release
//
// standalone_enclosure is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// standalone_enclosure is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with standalone_enclosure.  If not, see <https://www.gnu.org/licenses/>.
//
use <../smooth_prim.scad>

// Bottom inner (cavity) dimensions
iw = 20.5;
ih = 2.0;
il = 70.5;

// wall width
ww = 1.5;

// Part height
encl_h = 12;

difference() {
    // Rounded cube higher than we want we can lop off the top to make a flat mate
    // to the top bezel
    SmoothCube([iw + 2*ww, il + 2*ww, encl_h + 2], 2.5);
    
    // Cut-off the top to remove rounding
    translate([-1, -1, encl_h]) {
        cube([iw + 2*ww + 2, il + 2*ww + 2, 3]);
    }
    
    // Narrow inner cavity
    translate([ww + 1, ww, ww]) {
        cube([iw - 2, il, encl_h]);
    }
    
    // Wider cavity to form shelf for PCB
    translate([ww, ww, ww + ih]) {
           cube([iw, il, encl_h]);
    }
    
    // Cut-outs for connectors on PCB
    translate([0, 0, ww + ih + 1.6]) {
        // Probe
        translate([(iw + 2*ww)/2 - 3.5, -1, 0]) {
            cube([7, ww + 2, encl_h]);
        }
        
        // USB connector
        translate([iw + ww - 1, ww + 49, 0]) {
            cube([ww + 2, 9, encl_h]);
        }
        
        // DT71 connector
        translate([(iw + 2*ww)/2 - 4, ww + il - 1, 0]) {
            cube([8, ww + 2, encl_h]);
        }
        
        // Negative terminal wire
        translate([-1, ww + 61, 4]) {
            cube([ww + 2, 1.5, encl_h]);
        }
    }
}