//
// Top half of an enclosure for Miniware DT71 battery and charger circuit.
//
// Dimensions are mm
//
// Version 1.0 - Initial release
//
// standalone_enclosure is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// standalone_enclosure is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with standalone_enclosure.  If not, see <https://www.gnu.org/licenses/>.
//
use <../smooth_prim.scad>

// Inner cavity dimensions
iw = 20.5;
il = 70.5;

// wall width
ww = 1.5;

// Base height
base_h = 12;


// Bezel
difference() {
    // Rounded cube higher than we want we can lop off the top to make a flat mate
    // to the top bezel
    SmoothCube([iw + 2*ww, il + 2*ww, ww + 2], 2);
    
    // Cut-off the top to remove rounding
    translate([-1, -1, ww]) {
        cube([iw + 2*ww + 2, il + 2*ww + 2, 3]);
    }
    
    // Charge LED
    translate([ww + iw - 2.5 , ww + 50, 0.25]) {
        cylinder(r = 1.5, h = ww, $fn=60);
    }
}

// Mating features
translate([0, 0, ww]) {
    // Probe (5.1 = base_ww + base_ih + PCB 1.6mm, 1.5 = probe thickness)
    translate([(iw + 2*ww)/2 - 3.5, 0, 0]) {
        cube([7, ww, base_h - (5.1 + 1.5)]);
    }
    
    // USB connector
    translate([0, ww + 49, 0]) {
        cube([ww, 9, base_h - (5.1 + 4.1)]);
    }
    
    // DT71 connector
    translate([(iw + 2*ww)/2 -4, ww + il, 0]) {
        cube([8, ww, base_h - (5.1 + 6.1)]);
    }
    
    // PCB hold downs
    translate([ww, ww + 1, 0]) {
        cube([ww, 4, base_h - 5.1]);
    }
    
    translate([ww, il - 2 * ww - 1, 0]) {
        cube([ww, 4, base_h - 5.1]);
    }
    
    translate([iw, ww + 1, 0]) {
        cube([ww, 4, base_h - 5.1]);
    }
    
    translate([iw, il - 2 * ww - 1, 0]) {
        cube([ww, 4, base_h - 5.1]);
    }
}
