//
// Probe enclosure for re-purposed Miniware DT71 probe (with wire)
//
// Two identical halves designed to be glued together.
//
// Dimensions are mm
//
// Version 1.0 - Initial release
//
// standalone_enclosure is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// standalone_enclosure is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with standalone_enclosure.  If not, see <https://www.gnu.org/licenses/>.
//
use <../smooth_prim.scad>

w = 7;
h = 4;
l = 80;

difference() {
    // Rounded cube higher than we want for half so we can leave the rounded bottom
    // side and lop-off the top to make a smooth mating surface for the other half
    SmoothCube([w, l, (h/2) + 1], 1);
    
    // Cut-off top to remove rounding
    translate([-1, -1, h/2]) {
        cube([w+2, l+2, 2]);
    }
    
    // Cut-out for probe (5.25 W x 1.5 H x 18 L
    translate([w/2 - (5.25/2), -1, (h/2) - 0.75]) {
        cube([5.25, 18, 1.5]);
    }
    
    // Cut-out for probe screw or mounting peg
    translate([w/2, 6, -1]) {
        cylinder(h=h+1, r=0.85, $fn=60);
    }
    
    // Cut-out for wire (1.5mm)
    translate([2.75, -1, 1.25]) {
        cube([1.5, l+2, 1.5]);
    }
}